@@ -41,6 +41,10 @@
 static void override_debug_option(
     struct vpe_debug_options *debug, const struct vpe_debug_options *user_debug)
 {
+    if ((debug == NULL) || (user_debug == NULL)) {
+        return;
+    }
+
     if (user_debug->flags.bg_bit_depth)
         debug->bg_bit_depth = user_debug->bg_bit_depth;
 
@@ -89,9 +93,6 @@ static void override_debug_option(
     if (user_debug->flags.bypass_post_csc)
         debug->bypass_post_csc = user_debug->bypass_post_csc;
 
-    if (user_debug->flags.force_tf_calculation)
-        debug->force_tf_calculation = user_debug->force_tf_calculation;
-
     if (user_debug->flags.clamping_setting) {
         debug->clamping_setting = user_debug->clamping_setting;
         debug->clamping_params  = user_debug->clamping_params;
@@ -117,6 +118,9 @@ static void override_debug_option(
 
     if (user_debug->flags.skip_optimal_tap_check)
         debug->skip_optimal_tap_check = user_debug->skip_optimal_tap_check;
+
+    if (user_debug->flags.bypass_blndgam)
+        debug->bypass_blndgam = user_debug->bypass_blndgam;
 }
 
 #ifdef VPE_BUILD_1_1
